@@ -179,12 +179,13 @@ class Account(BaseObject):
     def email(self):
         return self.loginname
 
-    # PAS BasicUser implementation
-    def getId(self):
-        """Return the userid. For client accounts the login name is also
-        used as userid."""
+    # This synchs naming with euphorie.content.user.IUser and is needed by the
+    # authentication tools.
+    @property
+    def login(self):
         return self.loginname
 
+    # PAS BasicUser implementation
     def getUserName(self):
         """Return the login name."""
         return self.loginname
@@ -447,8 +448,8 @@ class Risk(SurveyTreeItem):
                 onupdate="CASCADE", ondelete="CASCADE"),
             primary_key=True)
     risk_id = schema.Column(types.String(16), nullable=False)
-    risk_type = schema.Column(Enum(["risk", "policy", "top5"]),
-        default="risk", nullable=False, index=True)
+    risk_type = schema.Column(Enum([u"risk", u"policy", u"top5"]),
+        default=u"risk", nullable=False, index=True)
     identification = schema.Column(Enum([None, u"yes", u"no", "n/a"]))
     frequency = schema.Column(types.Integer())
     effect = schema.Column(types.Integer())
@@ -476,8 +477,10 @@ class ActionPlan(BaseObject):
     reference = schema.Column(types.Text())
 
     risk = orm.relation(Risk,
-            backref=orm.backref("action_plans",
-                                cascade="all, delete, delete-orphan"))
+            backref=orm.backref(
+                "action_plans",
+                order_by=id,
+                cascade="all, delete, delete-orphan"))
 
 
 _instrumented = False
@@ -517,56 +520,56 @@ MODULE_WITH_RISK_FILTER = \
     sql.and_(SurveyTreeItem.type == "module",
              SurveyTreeItem.skip_children == False,
              sql.exists(sql.select([node.id]).where(sql.and_(
-                   node.session_id == SurveyTreeItem.session_id,
-                   node.id == Risk.sql_risk_id,
-                   node.type == "risk",
-                   Risk.identification == "no",
-                   node.depth > SurveyTreeItem.depth,
-                   node.path.like(SurveyTreeItem.path + "%")))))
+                 node.session_id == SurveyTreeItem.session_id,
+                 node.id == Risk.sql_risk_id,
+                 node.type == u"risk",
+                 Risk.identification == u"no",
+                 node.depth > SurveyTreeItem.depth,
+                 node.path.like(SurveyTreeItem.path + "%")))))
 
 MODULE_WITH_RISK_OR_TOP5_FILTER = \
-    sql.and_(SurveyTreeItem.type == "module",
+    sql.and_(SurveyTreeItem.type == u"module",
              SurveyTreeItem.skip_children == False,
              sql.exists(sql.select([node.id]).where(sql.and_(
-                   node.session_id == SurveyTreeItem.session_id,
-                   node.id == Risk.sql_risk_id,
-                   node.type == "risk",
-                   sql.or_(Risk.identification == "no",
-                           Risk.risk_type == "top5"),
-                   node.depth > SurveyTreeItem.depth,
-                   node.path.like(SurveyTreeItem.path + "%")))))
+                 node.session_id == SurveyTreeItem.session_id,
+                 node.id == Risk.sql_risk_id,
+                 node.type == "risk",
+                 sql.or_(Risk.identification == u"no",
+                     Risk.risk_type == u"top5"),
+                 node.depth > SurveyTreeItem.depth,
+                 node.path.like(SurveyTreeItem.path + "%")))))
 
 MODULE_WITH_RISK_NO_TOP5_NO_POLICY_FILTER = \
     sql.and_(SurveyTreeItem.type == "module",
              SurveyTreeItem.skip_children == False,
              sql.exists(sql.select([node.id]).where(sql.and_(
-                   node.session_id == SurveyTreeItem.session_id,
-                   node.id == Risk.sql_risk_id,
-                   node.type == "risk",
-                   sql.not_(Risk.risk_type.in_(["top5", "policy"])),
-                   Risk.identification == "no",
-                   node.depth > SurveyTreeItem.depth,
-                   node.path.like(SurveyTreeItem.path + "%")))))
+                 node.session_id == SurveyTreeItem.session_id,
+                 node.id == Risk.sql_risk_id,
+                 node.type == u"risk",
+                 sql.not_(Risk.risk_type.in_([u"top5", u"policy"])),
+                 Risk.identification == u"no",
+                 node.depth > SurveyTreeItem.depth,
+                 node.path.like(SurveyTreeItem.path + "%")))))
 
 RISK_PRESENT_FILTER = \
-      sql.and_(SurveyTreeItem.type == "risk",
-               sql.exists(sql.select([Risk.sql_risk_id]).where(sql.and_(
-                   Risk.sql_risk_id == SurveyTreeItem.id,
-                   Risk.identification == "no"))))
+    sql.and_(SurveyTreeItem.type == "risk",
+            sql.exists(sql.select([Risk.sql_risk_id]).where(sql.and_(
+                Risk.sql_risk_id == SurveyTreeItem.id,
+                Risk.identification == u"no"))))
 
 RISK_PRESENT_OR_TOP5_FILTER = \
-      sql.and_(SurveyTreeItem.type == "risk",
-               sql.exists(sql.select([Risk.sql_risk_id]).where(sql.and_(
-                   Risk.sql_risk_id == SurveyTreeItem.id,
-                   sql.or_(Risk.identification == "no",
-                           Risk.risk_type == "top5")))))
+    sql.and_(SurveyTreeItem.type == "risk",
+            sql.exists(sql.select([Risk.sql_risk_id]).where(sql.and_(
+                Risk.sql_risk_id == SurveyTreeItem.id,
+                sql.or_(Risk.identification == u"no",
+                    Risk.risk_type == u"top5")))))
 
 RISK_PRESENT_NO_TOP5_NO_POLICY_FILTER = \
-      sql.and_(SurveyTreeItem.type == "risk",
-               sql.exists(sql.select([Risk.sql_risk_id]).where(sql.and_(
-                   Risk.sql_risk_id == SurveyTreeItem.id,
-                   sql.not_(Risk.risk_type.in_(['top5', 'policy'])),
-                   Risk.identification == "no"))))
+    sql.and_(SurveyTreeItem.type == "risk",
+            sql.exists(sql.select([Risk.sql_risk_id]).where(sql.and_(
+                Risk.sql_risk_id == SurveyTreeItem.id,
+                sql.not_(Risk.risk_type.in_([u'top5', u'policy'])),
+                Risk.identification == u"no"))))
 del node
 
 __all__ = ["SurveySession", "Module", "Risk", "ActionPlan",
